@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: commands.c,v 1.14 1998/10/15 20:33:13 roessler Exp $";
+static const char rcsid[]="$Id: commands.c,v 1.15 1998/10/16 09:53:53 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -535,7 +535,7 @@ static void set_copy_flags(HEADER *hdr, int decode, int decrypt, int *cmflags, i
 
   if(decode)
   {
-    *chflags = CH_MIME | CH_TXTPLAIN;
+    *chflags = CH_XMIT | CH_MIME | CH_TXTPLAIN;
     *cmflags = M_CM_DECODE;
   }
 
