@@ -1,4 +1,4 @@
-static char rcsid[]="$Id: dotlock.c,v 1.3 1998/10/13 20:44:57 roessler Exp $";
+static const char rcsid[]="$Id: dotlock.c,v 1.5 1998/10/15 20:33:21 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * Copyright (C) 1998 Thomas Roessler <roessler@guug.de>
@@ -29,6 +29,10 @@ static char rcsid[]="$Id: dotlock.c,v 1.3 1998/10/13 20:44:57 roessler Exp $";
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef HAVE_GETOPT_H
+#include <getopt.h>
+#endif
+
 #include <unistd.h>
 #include <dirent.h>
 #include <sys/file.h>
