@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: init.c,v 1.19 1998/10/15 20:33:38 roessler Exp $";
+static const char rcsid[]="$Id: init.c,v 1.20 1998/10/19 08:42:41 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -1548,10 +1548,13 @@ void mutt_init (int skip_sys_rc, LIST *commands)
     Fqdn = safe_strdup ("@");
   else
 #endif /* DOMAIN */
+    if (*DOMAIN != '@')
   {
     Fqdn = safe_malloc (strlen (DOMAIN) + strlen (NONULL(Hostname)) + 2);
     sprintf (Fqdn, "%s.%s", NONULL(Hostname), DOMAIN);
   }
+  else
+    Fqdn = safe_strdup(NONULL(Hostname));
 
   if ((p = getenv ("MAIL")))
     Spoolfile = safe_strdup (p);
