@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: keymap.c,v 1.14 1998/10/15 20:33:39 roessler Exp $";
+static const char rcsid[]="$Id: keymap.c,v 1.16 1998/10/20 20:23:00 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -231,7 +231,8 @@ static int get_op (struct binding_t *bindings, const char *start, size_t len)
 
   for (i = 0; bindings[i].name; i++)
   {
-    if (!strncasecmp (start, bindings[i].name, len))
+    if (!strncasecmp (start, bindings[i].name, len) &&   
+	strlen (bindings[i].name) == len)
       return bindings[i].op;
   }
 
@@ -477,7 +478,7 @@ int km_expand_key (char *s, size_t len, struct keymap_t *map)
   FOREVER
   {
     strfcpy (s, km_keyname (map->keys[p]), len);
-    len -= (1 + (l = strlen (s)));
+    len -= (l = strlen (s));
 
     if (++p >= map->len || !len)
       return (1);
