@@ -1,4 +1,4 @@
-static char rcsid[]="$Id: parse.c,v 1.5 1998/10/13 20:45:45 roessler Exp $";
+static const char rcsid[]="$Id: parse.c,v 1.8 1998/10/15 20:33:48 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -126,6 +126,8 @@ int mutt_check_encoding (const char *c)
     return (ENCQUOTEDPRINTABLE);
   else if (strncasecmp ("base64", c, sizeof("base64")-1) == 0)
     return (ENCBASE64);
+  else if (strncasecmp ("x-uuencode", c, sizeof("x-uuencode")-1) == 0)
+    return (ENCUUENCODED);
   else
     return (ENCOTHER);
 }
@@ -421,7 +423,7 @@ BODY *mutt_parse_messageRFC822 (FILE *fp, BODY *parent)
 
   parent->hdr = mutt_new_header ();
   parent->hdr->offset = ftell (fp);
-  parent->hdr->env = mutt_read_rfc822_header (fp, parent->hdr);
+  parent->hdr->env = mutt_read_rfc822_header (fp, parent->hdr, 0);
   msg = parent->hdr->content;
 
   /* ignore the length given in the content-length since it could be wrong
@@ -833,12 +835,13 @@ void mutt_parse_mime_message (CONTEXT *ctx, HEADER *cur)
  *
  * f		stream to read from
  *
- * hdr		header structure of current message (optional).  If hdr is
- *		NULL, then we are reading a postponed message, or called
- *		from mutt_edit_headers() so we should keep a list of the
- *		user-defined headers.
+ * hdr		header structure of current message (optional).
+ * 
+ * user_hdrs	If set, store user headers.  Used for edit-message and 
+ * 		postpone modes.
+ * 
  */
-ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr)
+ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr, short user_hdrs)
 {
   ENVELOPE *e = mutt_new_envelope();
   LIST *last = NULL;
@@ -1154,7 +1157,7 @@ ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr)
     }
 
      /* Keep track of the user-defined headers */
-    if (!matched)
+    if (!matched && user_hdrs)
     {
       if (last)
       {
