@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: postpone.c,v 1.14 1998/10/15 20:33:56 roessler Exp $";
+static const char rcsid[]="$Id: postpone.c,v 1.16 1998/10/19 20:08:10 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -422,6 +422,7 @@ int mutt_edit_message (CONTEXT *ctx, HEADER *newhdr, HEADER *hdr)
       safe_free ((void *) &b->filename);
       b->filename = safe_strdup (file);
       b->unlink = 1;
+      mutt_stamp_attachment (b);
       mutt_free_body (&b->parts);
       b = b->next;
     }
@@ -437,6 +438,14 @@ int mutt_edit_message (CONTEXT *ctx, HEADER *newhdr, HEADER *hdr)
       return (-1);
     }
     newhdr->content = mutt_make_file_attach (file);
+    
+    FREE (&newhdr->content->subtype);
+    FREE (&newhdr->content->xtype);
+    
+    newhdr->content->type = hdr->content->type;
+    newhdr->content->xtype = safe_strdup (hdr->content->xtype);
+    newhdr->content->subtype = safe_strdup (hdr->content->subtype);
+    
     newhdr->content->use_disp = 0;	/* no content-disposition */
     newhdr->content->unlink = 1;	/* delete when we are done */
   }
